summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorMary Ruthven <mruthven@chromium.org>2021-01-05 17:08:19 -0800
committerCommit Bot <commit-bot@chromium.org>2021-01-06 23:07:44 +0000
commitade6b1e007428e85dc9b69e9a9c259bc6622f0d4 (patch)
tree1804c0e4eeb027c4d59301c6086751189c728c4d /include
parent9b36fc44ad92c9524aece3830dc6fd76acd4945a (diff)
downloadchrome-ec-ade6b1e007428e85dc9b69e9a9c259bc6622f0d4.tar.gz
coil: rename sleepmasks
BUG=b:175244613 TEST=make buildall -j Change-Id: I693fa068dc9bbf4babb1a63e35d4536f5eba1e88 Signed-off-by: Mary Ruthven <mruthven@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2613460 Reviewed-by: Namyoon Woo <namyoon@chromium.org>
Diffstat (limited to 'include')
-rw-r--r--include/system.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/system.h b/include/system.h
index 4862ad2dc0..60a50c6975 100644
--- a/include/system.h
+++ b/include/system.h
@@ -419,14 +419,15 @@ enum {
*/
SLEEP_MASK_AP_RUN = BIT(0), /* the main CPU is running */
SLEEP_MASK_UART = BIT(1), /* UART communication ongoing */
- SLEEP_MASK_I2C_MASTER = BIT(2), /* I2C master communication ongoing */
+ SLEEP_MASK_I2C_CONTROLLER
+ = BIT(2), /* I2C communication ongoing */
SLEEP_MASK_CHARGING = BIT(3), /* Charging loop ongoing */
SLEEP_MASK_USB_PWR = BIT(4), /* USB power loop ongoing */
SLEEP_MASK_USB_PD = BIT(5), /* USB PD device connected */
SLEEP_MASK_SPI = BIT(6), /* SPI communications ongoing */
- SLEEP_MASK_I2C_SLAVE = BIT(7), /* I2C slave communication ongoing */
+ SLEEP_MASK_I2C_PERIPH = BIT(7), /* I2C periph communication ongoing */
SLEEP_MASK_AP_RO_VERIFICATION
- = BIT(8), /* AP RO verification failure. */
+ = BIT(8), /* AP RO verification failure. */
SLEEP_MASK_USB_DEVICE = BIT(9), /* Generic USB device in use */
SLEEP_MASK_PWM = BIT(10), /* PWM output is enabled */
SLEEP_MASK_PHYSICAL_PRESENCE = BIT(11), /* Physical presence